<?php

namespace Drupal\content_entity_builder\Plugin\BaseFieldConfig;

use Drupal\Core\Form\FormStateInterface;
use Drupal\content_entity_builder\ConfigurableBaseFieldConfigBase;
use Drupal\content_entity_builder\ContentTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * StringItemBaseFieldConfig.
 *
 * @BaseFieldConfig(
 *   id = "string_base_field_config",
 *   label = @Translation("Text (plain)"),
 *   description = @Translation("A field containing a plain string value."),
 *   field_type = "string",
 *   category = @Translation("Text")
 * )
 */
class StringItemBaseFieldConfig extends ConfigurableBaseFieldConfigBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array(
      'max_length' => 255,
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
  
    $form['max_length'] = [
      '#type' => 'number',
      '#title' => t('Maximum length'),
      '#default_value' => $this->configuration['max_length'],
      '#required' => TRUE,
      '#description' => t('The maximum length of the field in characters.'),
      '#min' => 1,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
	$this->configuration['max_length'] = $form_state->getValue('max_length');
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildBaseFieldDefinition() {
    $field_type = $this->getFieldType();
    $label = $this->getLabel(); 
    $weight = $this->getWeight();
    $default_value = $this->getDefaultValue();		
    $base_field_definition = BaseFieldDefinition::create($field_type)
	    ->setLabel(t($label))
		->setDefaultValue($default_value)
		->setDisplayOptions('view', array(
			'label' => 'above',
			'type' => 'string',
			'weight' => $weight,
		))
		->setDisplayOptions('form', array(
			'type' => 'text_textfield',
			'weight' => $weight,
		))		
        ->setDisplayConfigurable('form', TRUE)
	    ->setDisplayConfigurable('view', TRUE);			

    return $base_field_definition;
  }
}
