<?php

namespace Drupal\content_entity_builder\Plugin\BaseFieldConfig;

use Drupal\Core\Form\FormStateInterface;
use Drupal\content_entity_builder\ConfigurableBaseFieldConfigBase;
use Drupal\content_entity_builder\ContentTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * StringItemBaseFieldConfig.
 *
 * @BaseFieldConfig(
 *   id = "string_long_base_field_config",
 *   label = @Translation("Text (plain, long)"),
 *   description = @Translation("A field containing a long string value."),
 *   field_type = "string_long",
 *   category = @Translation("Text")
 * )
 */
class StringLongItemBaseFieldConfig extends ConfigurableBaseFieldConfigBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildBaseFieldDefinition() {
    $field_type = $this->getFieldType();
    $label = $this->getLabel(); 
    $weight = $this->getWeight();
    $default_value = $this->getDefaultValue();		
    $base_field_definition = BaseFieldDefinition::create($field_type)
	    ->setLabel(t($label))
		->setDefaultValue($default_value)
		->setDisplayOptions('view', array(
			'label' => 'above',
			'type' => 'basic_string',
			'weight' => $weight,
		))
		->setDisplayOptions('form', array(
			'type' => 'string_textarea',
			'weight' => $weight,
		))		
        ->setDisplayConfigurable('form', TRUE)
	    ->setDisplayConfigurable('view', TRUE);			

    return $base_field_definition;
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildDefaultValueForm() {
    $default_value_element = [
      '#type' => 'textarea',
      '#title' => $this->t('Default value'),
      '#default_value' => $this->getDefaultValue(),
    ];

    return  $default_value_element;	  
  }   
}
